@@ -10,13 +10,13 @@ import sys
 
 import Hamlib
 
-def StartUp():
+def StartUp(verbose):
     """Simple script to test the Hamlib.py module with Python2."""
 
     print "%s: Python %s; %s\n" \
           % (sys.argv[0], sys.version.split()[0], Hamlib.cvar.hamlib_version)
 
-    Hamlib.rig_set_debug(Hamlib.RIG_DEBUG_NONE)
+    Hamlib.rig_set_debug([Hamlib.RIG_DEBUG_NONE, Hamlib.RIG_DEBUG_VERBOSE][verbose])
 
     # Init RIG_MODEL_DUMMY
     my_rig = Hamlib.Rig(Hamlib.RIG_MODEL_DUMMY)
@@ -25,15 +25,12 @@ def StartUp():
 
     my_rig.open()
 
-    # 1073741944 is token value for "itu_region"
-    # but using get_conf is much more convenient
-    region = my_rig.get_conf(1073741944)
     rpath = my_rig.get_conf("rig_pathname")
     retry = my_rig.get_conf("retry")
 
     print "status(str):\t\t", Hamlib.rigerror(my_rig.error_status)
-    print "get_conf:\t\tpath = %s, retry = %s, ITU region = %s" \
-          % (rpath, retry, region)
+    print "get_conf:\t\tpath = %s, retry = %s" \
+          % (rpath, retry)
 
     my_rig.set_freq(Hamlib.RIG_VFO_B, 5700000000)
     my_rig.set_vfo(Hamlib.RIG_VFO_B)
@@ -50,7 +47,6 @@ def StartUp():
 
     print "mode:\t\t\t", Hamlib.rig_strrmode(mode), "\nbandwidth:\t\t", width
 
-    print "ITU_region:\t\t", my_rig.state.itu_region
     print "Backend copyright:\t", my_rig.caps.copyright
     print "Model:\t\t\t", my_rig.caps.model_name
     print "Manufacturer:\t\t", my_rig.caps.mfg_name
@@ -58,13 +54,13 @@ def StartUp():
     print "Backend status:\t\t", Hamlib.rig_strstatus(my_rig.caps.status)
     print "Rig info:\t\t", my_rig.get_info()
 
-    my_rig.set_level("VOX",  1)
+    my_rig.set_level("VOXDELAY",  1)
 
-    print "VOX level:\t\t", my_rig.get_level_i("VOX")
+    print "VOX delay:\t\t", my_rig.get_level_i("VOXDELAY")
 
-    my_rig.set_level(Hamlib.RIG_LEVEL_VOX, 5)
+    my_rig.set_level(Hamlib.RIG_LEVEL_VOXDELAY, 5)
 
-    print "VOX level:\t\t", my_rig.get_level_i(Hamlib.RIG_LEVEL_VOX)
+    print "VOX delay:\t\t", my_rig.get_level_i(Hamlib.RIG_LEVEL_VOXDELAY)
 
     af = 12.34
 
@@ -81,7 +77,7 @@ def StartUp():
     print "status(str):\t\t", Hamlib.rigerror(my_rig.error_status)
 
     chan = Hamlib.channel(Hamlib.RIG_VFO_B)
-    my_rig.get_channel(chan)
+    my_rig.get_channel(chan,1)
 
     print "get_channel status:\t", my_rig.error_status
     print "VFO:\t\t\t", Hamlib.rig_strvfo(chan.vfo), ", ", chan.freq
@@ -123,4 +119,4 @@ def StartUp():
 
 
 if __name__ == '__main__':
-    StartUp()
+    StartUp([0,1]["-v" in sys.argv])
