@@ -22,10 +22,6 @@
 
 /* Includes ------------------------------------------------------------------*/
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -33,12 +29,7 @@
 
 #include "hamlib/rig.h"
 #include "serial.h"
-#include "parallel.h"
-#include "cm108.h"
-#include "gpio.h"
 #include "misc.h"
-#include "tones.h"
-#include "idx_builtin.h"
 #include "register.h"
 
 #include "gs100.h"
@@ -80,7 +71,7 @@ struct gs100_priv_data
 /* Imported Functions --------------------------------------------------------*/
 
 struct ext_list *alloc_init_ext(const struct confparams *cfp);
-struct ext_list *find_ext(struct ext_list *elp, token_t token);
+struct ext_list *find_ext(struct ext_list *elp, hamlib_token_t token);
 
 /* Private function prototypes -----------------------------------------------*/
 
@@ -92,7 +83,8 @@ static int gomx_set(RIG *rig, int table, char *varname, char *varvalue);
 /**
  * Get variable from the GS100 configuration table
  */
-static int gomx_get(RIG *rig, int table, char *varname, char *varvalue);
+static int gomx_get(RIG *rig, int table, char *varname, const char *varvalue,
+                    int varvalue_len);
 
 /**
  * Sends a message to the GS100 and parses response lines
@@ -104,16 +96,10 @@ static int gomx_transaction(RIG *rig, char *message, char *response);
 /* GS100 transceiver control init */
 static int gs100_init(RIG *rig)
 {
-    __attribute__((unused)) struct gs100_priv_data *priv = (struct gs100_priv_data
-            *)rig->state.priv;
+    __attribute__((unused)) struct gs100_priv_data *priv;
 
     ENTERFUNC;
 
-    if (!rig || !rig->caps)
-    {
-        RETURNFUNC(-RIG_EINVAL);
-    }
-
     priv = (struct gs100_priv_data *)calloc(1, sizeof(struct gs100_priv_data));
 
     if (!priv)
@@ -121,10 +107,10 @@ static int gs100_init(RIG *rig)
         RETURNFUNC(-RIG_ENOMEM);
     }
 
-    rig->state.priv = (void *)priv;
+    STATE(rig)->priv = (void *)priv;
 
 #ifdef _LOCAL_SIMULATION_
-    rig->state.rigport.type.rig = RIG_PORT_NONE;  // just simulation
+    RIGPORT(rig)->type.rig = RIG_PORT_NONE;  // just simulation
     priv->freq_rx = rig->caps->rx_range_list1->startf;
     priv->freq_tx = rig->caps->tx_range_list1->startf;
 #endif
@@ -138,17 +124,14 @@ static int gs100_init(RIG *rig)
 /* GS100 transceiver control deinit */
 static int gs100_cleanup(RIG *rig)
 {
-    __attribute__((unused)) struct gs100_priv_data *priv = (struct gs100_priv_data
-            *)rig->state.priv;
-
     ENTERFUNC;
 
-    if (rig->state.priv)
+    if (STATE(rig)->priv)
     {
-        free(rig->state.priv);
+        free(STATE(rig)->priv);
     }
 
-    rig->state.priv = NULL;
+    STATE(rig)->priv = NULL;
 
     RETURNFUNC(RIG_OK);
 }
@@ -183,14 +166,14 @@ static int gs100_close(RIG *rig)
 
 
 /* GS100 transceiver set configuration */
-static int gs100_set_conf(RIG *rig, token_t token, const char *val)
+static int gs100_set_conf(RIG *rig, hamlib_token_t token, const char *val)
 {
     __attribute__((unused)) struct gs100_priv_data *priv = (struct gs100_priv_data
-            *)rig->state.priv;
+            *)STATE(rig)->priv;
 
     ENTERFUNC;
 
-    priv = (struct gs100_priv_data *)rig->state.priv;
+    priv = (struct gs100_priv_data *)STATE(rig)->priv;
 
     switch (token)
     {
@@ -209,14 +192,14 @@ static int gs100_set_conf(RIG *rig, token_t token, const char *val)
 
 
 /* GS100 transceiver get configuration */
-static int gs100_get_conf(RIG *rig, token_t token, char *val)
+static int gs100_get_conf(RIG *rig, hamlib_token_t token, char *val)
 {
     __attribute__((unused)) struct gs100_priv_data *priv = (struct gs100_priv_data
-            *)rig->state.priv;
+            *)STATE(rig)->priv;
 
     ENTERFUNC;
 
-    priv = (struct gs100_priv_data *)rig->state.priv;
+    priv = (struct gs100_priv_data *)STATE(rig)->priv;
 
     switch (token)
     {
@@ -234,8 +217,11 @@ static int gs100_get_conf(RIG *rig, token_t token, char *val)
 /* GS100 transceiver set receiver frequency */
 static int gs100_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
-    __attribute__((unused)) struct gs100_priv_data *priv = (struct gs100_priv_data
-            *)rig->state.priv;
+#ifdef _LOCAL_SIMULATION_
+    __attribute__((unused)) const struct gs100_priv_data *priv =
+        (struct gs100_priv_data
+         *)STATE(rig)->priv;
+#endif
     char fstr[20], value[20];
     int retval;
 
@@ -266,8 +252,11 @@ static int gs100_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 /* GS100 transceiver get receiver frequency */
 static int gs100_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
-    __attribute__((unused)) struct gs100_priv_data *priv = (struct gs100_priv_data
-            *)rig->state.priv;
+#ifdef _LOCAL_SIMULATION_
+    __attribute__((unused)) const struct gs100_priv_data *priv =
+        (struct gs100_priv_data
+         *)STATE(rig)->priv;
+#endif
     char resp[20];
     int retval;
     freq_t f;
@@ -275,7 +264,7 @@ static int gs100_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
     ENTERFUNC;
 
     // perform the get command
-    retval = gomx_get(rig, GOM_CONFIG_TAB_RX, "freq", resp);
+    retval = gomx_get(rig, GOM_CONFIG_TAB_RX, "freq", resp, sizeof(resp));
 
     if (retval != RIG_OK) { RETURNFUNC(retval); }
 
@@ -300,8 +289,11 @@ static int gs100_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 /* GS100 transceiver set transmitter frequency */
 static int gs100_set_tx_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
-    __attribute__((unused)) struct gs100_priv_data *priv = (struct gs100_priv_data
-            *)rig->state.priv;
+#ifdef _LOCAL_SIMULATION_
+    __attribute__((unused)) const struct gs100_priv_data *priv =
+        (struct gs100_priv_data
+         *)STATE(rig)->priv;
+#endif
     char fstr[20], value[20];
     int retval;
 
@@ -332,8 +324,11 @@ static int gs100_set_tx_freq(RIG *rig, vfo_t vfo, freq_t freq)
 /* GS100 transceiver get transmitter frequency */
 static int gs100_get_tx_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
-    __attribute__((unused)) struct gs100_priv_data *priv = (struct gs100_priv_data
-            *)rig->state.priv;
+#ifdef _LOCAL_SIMULATION_
+    __attribute__((unused)) const struct gs100_priv_data *priv =
+        (struct gs100_priv_data
+         *)STATE(rig)->priv;
+#endif
     char resp[20];
     int retval;
     freq_t f;
@@ -341,7 +336,7 @@ static int gs100_get_tx_freq(RIG *rig, vfo_t vfo, freq_t *freq)
     ENTERFUNC;
 
     // perform the get command
-    retval = gomx_get(rig, GOM_CONFIG_TAB_TX, "freq", resp);
+    retval = gomx_get(rig, GOM_CONFIG_TAB_TX, "freq", resp, sizeof(resp));
 
     if (retval != RIG_OK) { RETURNFUNC(retval); }
 
@@ -385,7 +380,7 @@ struct rig_caps GS100_caps =
     .mfg_name = "GOMSPACE",
     .version = "20211117.0",
     .copyright = "LGPL",
-    .status = RIG_STATUS_BETA,
+    .status = RIG_STATUS_STABLE,
     .rig_type = RIG_TYPE_TRANSCEIVER,
     .targetable_vfo = 0,
     .ptt_type = RIG_PTT_NONE,
@@ -445,7 +440,7 @@ struct rig_caps GS100_caps =
 static int gomx_set(RIG *rig, int table, char *varname, char *varvalue)
 {
     __attribute__((unused)) struct gs100_priv_data *priv = (struct gs100_priv_data
-            *)rig->state.priv;
+            *)STATE(rig)->priv;
     int retval;
     char msg[BUFSZ], resp[BUFSZ];
 
@@ -480,12 +475,14 @@ static int gomx_set(RIG *rig, int table, char *varname, char *varvalue)
 
 
 /* Get variable from the GS100 configuration table */
-static int gomx_get(RIG *rig, int table, char *varname, char *varvalue)
+static int gomx_get(RIG *rig, int table, char *varname, const char *varvalue,
+                    int varvalue_len)
 {
     __attribute__((unused)) struct gs100_priv_data *priv = (struct gs100_priv_data
-            *)rig->state.priv;
+            *)STATE(rig)->priv;
     int retval;
     char msg[BUFSZ], resp[BUFSZ], *c;
+    char fmt[32];
 
     assert(rig != NULL);
     assert(varname != NULL);
@@ -504,7 +501,7 @@ static int gomx_get(RIG *rig, int table, char *varname, char *varvalue)
     }
 
     // get the variable
-    sprintf(msg, "param get %s\n", varname);
+    sprintf(msg, "param get %19s\n", varname);
     retval = gomx_transaction(rig, msg, resp);
 
     if (retval != RIG_OK) { return (retval); }
@@ -512,7 +509,9 @@ static int gomx_get(RIG *rig, int table, char *varname, char *varvalue)
     // check response and extract the value
     if ((c = strchr(resp, '=')) == NULL) { return (-RIG_EPROTO); }
 
-    if (sscanf(c + 1, "%s", varvalue) != 1) { return (-RIG_EPROTO); }
+    snprintf(fmt, sizeof(fmt), "%%%ds", varvalue_len);
+
+    if (sscanf(c + 1, fmt, varvalue_len) != 1) { return (-RIG_EPROTO); }
 
     return (RIG_OK);
 }
@@ -521,9 +520,7 @@ static int gomx_get(RIG *rig, int table, char *varname, char *varvalue)
 /* Sends a message to the GS100 and parses response lines */
 static int gomx_transaction(RIG *rig, char *message, char *response)
 {
-    __attribute__((unused)) struct gs100_priv_data *priv = (struct gs100_priv_data
-            *)rig->state.priv;
-    struct rig_state *rs;
+    hamlib_port_t *rp;
     int retval, n = 0;
     char buf[BUFSZ];
 
@@ -534,20 +531,18 @@ static int gomx_transaction(RIG *rig, char *message, char *response)
     rig_debug(RIG_DEBUG_TRACE, "%s: msg='%s'\n", __func__,
               message == NULL ? "NULL" : message);
 
-    // access to private variables
-    rs = &rig->state;
-    priv = (struct gs100_priv_data *)rs->priv;
+    rp = RIGPORT(rig);
 
     // send message to the transceiver
-    rig_flush(&rs->rigport);
-    retval = write_block(&rs->rigport, (uint8_t *)message, strlen(message));
+    rig_flush(rp);
+    retval = write_block(rp, (uint8_t *)message, strlen(message));
 
     if (retval != RIG_OK) { return (retval); }
 
     while (1)
     {
         // read the response line
-        retval = read_string(&rs->rigport, (unsigned char *)buf, BUFSZ,
+        retval = read_string(rp, (unsigned char *)buf, BUFSZ,
                              (const char *)GOM_STOPSET, 0, strlen(GOM_STOPSET), 0);
 
         if (retval < 0) { return (retval); }
