@@ -19,8 +19,6 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 
 #include "hamlib/rig.h"
@@ -56,7 +54,7 @@ static const struct icom_priv_caps ic726_priv_caps =
     ic737_ts_sc_list
 };
 
-const struct rig_caps ic726_caps =
+struct rig_caps ic726_caps =
 {
     RIG_MODEL(RIG_MODEL_IC726),
     .model_name = "IC-726",
