@@ -19,14 +19,10 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <string.h>  /* String function definitions */
 
 #include "hamlib/rig.h"
 #include "serial.h"
-#include "misc.h"
-#include "cal.h"
 #include "register.h"
 
 #include "kachina.h"
@@ -62,33 +58,31 @@
 
 /*
  * kachina_transaction
- * We assume that rig!=NULL, rig->state!= NULL
+ * We assume that rig!=NULL, STATE(rig)!= NULL
  * Otherwise, you'll get a nice seg fault. You've been warned!
  * TODO: error case handling
  */
 static int kachina_transaction(RIG *rig, unsigned char cmd1, unsigned char cmd2)
 {
     int count, retval;
-    struct rig_state *rs;
+    hamlib_port_t *rp = RIGPORT(rig);
     unsigned char buf4[4];
 
-    rs = &rig->state;
-
     buf4[0] = STX;
     buf4[1] = cmd1;
     buf4[2] = cmd2;
     buf4[3] = ETX;
 
-    rig_flush(&rs->rigport);
+    rig_flush(rp);
 
-    retval = write_block(&rs->rigport, buf4, 4);
+    retval = write_block(rp, buf4, 4);
 
     if (retval != RIG_OK)
     {
         return retval;
     }
 
-    count = read_string(&rs->rigport, buf4, 1, "", 0, 0, 1);
+    count = read_string(rp, buf4, 1, "", 0, 0, 1);
 
     if (count != 1)
     {
@@ -102,11 +96,9 @@ static int kachina_trans_n(RIG *rig, unsigned char cmd1, const char *data,
                            int data_len)
 {
     int cmd_len, count, retval;
-    struct rig_state *rs;
+    hamlib_port_t *rp = RIGPORT(rig);
     unsigned char buf[16];
 
-    rs = &rig->state;
-
     buf[0] = STX;
     buf[1] = cmd1;
     memcpy(buf + 2, data, data_len);
@@ -114,16 +106,16 @@ static int kachina_trans_n(RIG *rig, unsigned char cmd1, const char *data,
 
     cmd_len = data_len + 3;
 
-    rig_flush(&rs->rigport);
+    rig_flush(rp);
 
-    retval = write_block(&rs->rigport, buf, cmd_len);
+    retval = write_block(rp, buf, cmd_len);
 
     if (retval != RIG_OK)
     {
         return retval;
     }
 
-    count = read_string(&rs->rigport, buf, 1, "", 0, 0, 1);
+    count = read_string(rp, buf, 1, "", 0, 0, 1);
 
     if (count != 1)
     {
@@ -177,12 +169,16 @@ int kachina_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
     /* transmit frequency */
     retval = kachina_trans_n(rig, 'T', (char *) freqbuf, 4);
 
-    if (retval != RIG_OK)
-    {
-        return retval;
-    }
+    return retval;
+}
 
-    return RIG_OK;
+int kachina_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
+{
+    char c = ptt == 0 ? 0x00 : 0x01;
+
+    int retval = kachina_trans_n(rig, 'x', &c, 1);
+
+    return retval;
 }
 
 /*
@@ -233,6 +229,7 @@ int kachina_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
     int i, count;
     unsigned char buf[32];
+    hamlib_port_t *rp = RIGPORT(rig);
 
     static const char rcv_signal_range[128] =
     {
@@ -265,9 +262,9 @@ int kachina_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
     /* telemetry sent to the PC automatically at a 50msec rate */
 
-    rig_flush(&rig->state.rigport);
+    rig_flush(rp);
 
-    count = read_string(&rig->state.rigport, buf, 31, rcv_signal_range,
+    count = read_string(rp, buf, 31, rcv_signal_range,
                         128, 0, 1);
 
     if (count < 1)
