@@ -25,8 +25,6 @@
 *
 */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 #include <string.h>  /* String function definitions */
 
@@ -415,12 +413,12 @@ struct ft900_priv_data
  *
  */
 
-const struct rig_caps ft900_caps =
+struct rig_caps ft900_caps =
 {
     RIG_MODEL(RIG_MODEL_FT900),
     .model_name =         "FT-900",
     .mfg_name =           "Yaesu",
-    .version =            "20200323.0",
+    .version =            "20241122.0",
     .copyright =          "LGPL",
     .status =             RIG_STATUS_STABLE,
     .rig_type =           RIG_TYPE_TRANSCEIVER,
@@ -561,15 +559,15 @@ static int ft900_init(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    rig->state.priv = (struct ft900_priv_data *) calloc(1,
-                      sizeof(struct ft900_priv_data));
+    STATE(rig)->priv = (struct ft900_priv_data *) calloc(1,
+                       sizeof(struct ft900_priv_data));
 
-    if (!rig->state.priv)                       /* whoops! memory shortage! */
+    if (!STATE(rig)->priv)                       /* whoops! memory shortage! */
     {
         return -RIG_ENOMEM;
     }
 
-    priv = rig->state.priv;
+    priv = STATE(rig)->priv;
 
     /* TODO: read pacing from preferences */
     priv->pacing = FT900_PACING_DEFAULT_VALUE; /* set pacing to minimum for now */
@@ -596,12 +594,12 @@ static int ft900_cleanup(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    if (rig->state.priv)
+    if (STATE(rig)->priv)
     {
-        free(rig->state.priv);
+        free(STATE(rig)->priv);
     }
 
-    rig->state.priv = NULL;
+    STATE(rig)->priv = NULL;
 
     return RIG_OK;
 }
@@ -614,7 +612,6 @@ static int ft900_cleanup(RIG *rig)
 
 static int ft900_open(RIG *rig)
 {
-    struct rig_state *rig_s;
     struct ft900_priv_data *priv;
     int err;
 
@@ -625,13 +622,12 @@ static int ft900_open(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft900_priv_data *)rig->state.priv;
-    rig_s = &rig->state;
+    priv = (struct ft900_priv_data *)STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: write_delay = %i msec\n",
-              __func__, rig_s->rigport.write_delay);
+              __func__, RIGPORT(rig)->write_delay);
     rig_debug(RIG_DEBUG_TRACE, "%s: post_write_delay = %i msec\n",
-              __func__, rig_s->rigport.post_write_delay);
+              __func__, RIGPORT(rig)->post_write_delay);
     rig_debug(RIG_DEBUG_TRACE,
               "%s: read pacing = %i\n", __func__, priv->pacing);
 
@@ -689,7 +685,7 @@ static int ft900_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft900_priv_data *)rig->state.priv;
+    priv = (struct ft900_priv_data *)STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
     rig_debug(RIG_DEBUG_TRACE, "%s: passed freq = %"PRIfreq" Hz\n", __func__, freq);
@@ -745,7 +741,7 @@ static int ft900_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft900_priv_data *)rig->state.priv;
+    priv = (struct ft900_priv_data *)STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -837,7 +833,7 @@ static int ft900_set_mode(RIG *rig, vfo_t vfo, rmode_t mode,
     rig_debug(RIG_DEBUG_TRACE, "%s: passed width = %li Hz\n",
               __func__, width);
 
-    priv = (struct ft900_priv_data *)rig->state.priv;
+    priv = (struct ft900_priv_data *)STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -901,6 +897,7 @@ static int ft900_set_mode(RIG *rig, vfo_t vfo, rmode_t mode,
         break;
 
     default:
+        rig_debug(RIG_DEBUG_ERR, "%s: mode %s not supported by FT900\n", __func__, rig_strrmode(mode));
         return -RIG_EINVAL;       /* sorry, wrong MODE */
     }
 
@@ -974,7 +971,7 @@ static int ft900_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
 
-    priv = (struct ft900_priv_data *)rig->state.priv;
+    priv = (struct ft900_priv_data *)STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -1118,7 +1115,7 @@ static int ft900_set_vfo(RIG *rig, vfo_t vfo)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
 
-    priv = (struct ft900_priv_data *)rig->state.priv;
+    priv = (struct ft900_priv_data *)STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -1198,7 +1195,7 @@ static int ft900_get_vfo(RIG *rig, vfo_t *vfo)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft900_priv_data *)rig->state.priv;
+    priv = (struct ft900_priv_data *)STATE(rig)->priv;
 
     /* Get flags for VFO status */
     err = ft900_get_update_data(rig, FT900_NATIVE_READ_FLAGS,
@@ -1304,7 +1301,7 @@ static int ft900_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft900_priv_data *)rig->state.priv;
+    priv = (struct ft900_priv_data *)STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
     rig_debug(RIG_DEBUG_TRACE, "%s: passed ptt = 0x%02x\n", __func__, ptt);
@@ -1368,7 +1365,7 @@ static int ft900_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft900_priv_data *)rig->state.priv;
+    priv = (struct ft900_priv_data *)STATE(rig)->priv;
 
     /* Get flags for VFO status */
     err = ft900_get_update_data(rig, FT900_NATIVE_READ_FLAGS,
@@ -1482,7 +1479,7 @@ static int ft900_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split,
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
 
-    priv = (struct ft900_priv_data *)rig->state.priv;
+    priv = (struct ft900_priv_data *)STATE(rig)->priv;
 
     /* Get flags for VFO split status */
     err = ft900_get_update_data(rig, FT900_NATIVE_READ_FLAGS,
@@ -1547,7 +1544,7 @@ static int ft900_set_rit(RIG *rig, vfo_t vfo, shortfreq_t rit)
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
     rig_debug(RIG_DEBUG_TRACE, "%s: passed rit = %li\n", __func__, rit);
 
-    priv = (struct ft900_priv_data *)rig->state.priv;
+    priv = (struct ft900_priv_data *)STATE(rig)->priv;
 
     /*
      * The assumption here is that the user hasn't changed
@@ -1633,7 +1630,7 @@ static int ft900_get_rit(RIG *rig, vfo_t vfo, shortfreq_t *rit)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: passed vfo = 0x%02x\n", __func__, vfo);
 
-    priv = (struct ft900_priv_data *)rig->state.priv;
+    priv = (struct ft900_priv_data *)STATE(rig)->priv;
 
     if (vfo == RIG_VFO_CURR)
     {
@@ -1786,7 +1783,7 @@ static int ft900_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
     rig_debug(RIG_DEBUG_TRACE, "%s: passed level = %s\n", __func__,
               rig_strlevel(level));
 
-    priv = (struct ft900_priv_data *)rig->state.priv;
+    priv = (struct ft900_priv_data *)STATE(rig)->priv;
 
     switch (level)
     {
@@ -1899,7 +1896,7 @@ static int ft900_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
  *              rl      expected length of returned data in octets
  *
  * Returns:     RIG_OK if all called functions are successful,
- *              otherwise returns error from called functiion
+ *              otherwise returns error from called function
  */
 
 static int ft900_get_update_data(RIG *rig, unsigned char ci, unsigned char rl)
@@ -1914,7 +1911,7 @@ static int ft900_get_update_data(RIG *rig, unsigned char ci, unsigned char rl)
         return -RIG_EINVAL;
     }
 
-    priv = (struct ft900_priv_data *)rig->state.priv;
+    priv = (struct ft900_priv_data *)STATE(rig)->priv;
 
     err = ft900_send_static_cmd(rig, ci);
 
@@ -1923,7 +1920,7 @@ static int ft900_get_update_data(RIG *rig, unsigned char ci, unsigned char rl)
         return err;
     }
 
-    n = read_block(&rig->state.rigport, priv->update_data, rl);
+    n = read_block(RIGPORT(rig), priv->update_data, rl);
 
     if (n < 0)
     {
@@ -1945,7 +1942,7 @@ static int ft900_get_update_data(RIG *rig, unsigned char ci, unsigned char rl)
  *              ci      Command index of the ncmd table
  *
  * Returns:     RIG_OK if all called functions are successful,
- *              otherwise returns error from called functiion
+ *              otherwise returns error from called function
  */
 
 static int ft900_send_static_cmd(RIG *rig, unsigned char ci)
@@ -1966,7 +1963,7 @@ static int ft900_send_static_cmd(RIG *rig, unsigned char ci)
         return -RIG_EINVAL;
     }
 
-    err = write_block(&rig->state.rigport, ncmd[ci].nseq, YAESU_CMD_LENGTH);
+    err = write_block(RIGPORT(rig), ncmd[ci].nseq, YAESU_CMD_LENGTH);
 
     if (err != RIG_OK)
     {
@@ -1988,7 +1985,7 @@ static int ft900_send_static_cmd(RIG *rig, unsigned char ci)
  *              p1-p4   Command parameters
  *
  * Returns:     RIG_OK if all called functions are successful,
- *              otherwise returns error from called functiion
+ *              otherwise returns error from called function
  */
 
 static int ft900_send_dynamic_cmd(RIG *rig, unsigned char ci,
@@ -2010,7 +2007,7 @@ static int ft900_send_dynamic_cmd(RIG *rig, unsigned char ci,
               "%s: passed p1 = 0x%02x, p2 = 0x%02x, p3 = 0x%02x, p4 = 0x%02x,\n",
               __func__, p1, p2, p3, p4);
 
-    priv = (struct ft900_priv_data *)rig->state.priv;
+    priv = (struct ft900_priv_data *)STATE(rig)->priv;
 
     if (ncmd[ci].ncomp)
     {
@@ -2026,7 +2023,7 @@ static int ft900_send_dynamic_cmd(RIG *rig, unsigned char ci,
     priv->p_cmd[P3] = p3;
     priv->p_cmd[P4] = p4;
 
-    err = write_block(&rig->state.rigport, (unsigned char *) &priv->p_cmd,
+    err = write_block(RIGPORT(rig), (unsigned char *) &priv->p_cmd,
                       YAESU_CMD_LENGTH);
 
     if (err != RIG_OK)
@@ -2049,7 +2046,7 @@ static int ft900_send_dynamic_cmd(RIG *rig, unsigned char ci,
  *              freq    freq_t frequency value
  *
  * Returns:     RIG_OK if all called functions are successful,
- *              otherwise returns error from called functiion
+ *              otherwise returns error from called function
  */
 
 static int ft900_send_dial_freq(RIG *rig, unsigned char ci, freq_t freq)
@@ -2069,7 +2066,7 @@ static int ft900_send_dial_freq(RIG *rig, unsigned char ci, freq_t freq)
     rig_debug(RIG_DEBUG_TRACE, "%s: passed ci = %i\n", __func__, ci);
     rig_debug(RIG_DEBUG_TRACE, "%s: passed freq = %"PRIfreq" Hz\n", __func__, freq);
 
-    priv = (struct ft900_priv_data *)rig->state.priv;
+    priv = (struct ft900_priv_data *)STATE(rig)->priv;
 
     if (ncmd[ci].ncomp)
     {
@@ -2087,7 +2084,7 @@ static int ft900_send_dial_freq(RIG *rig, unsigned char ci, freq_t freq)
     rig_debug(RIG_DEBUG_TRACE, fmt, __func__, (int64_t)from_bcd(priv->p_cmd,
               FT900_BCD_DIAL) * 10);
 
-    err = write_block(&rig->state.rigport, (unsigned char *) &priv->p_cmd,
+    err = write_block(RIGPORT(rig), (unsigned char *) &priv->p_cmd,
                       YAESU_CMD_LENGTH);
 
     if (err != RIG_OK)
@@ -2112,7 +2109,7 @@ static int ft900_send_dial_freq(RIG *rig, unsigned char ci, freq_t freq)
  *              p2      P2 value -- CLAR_OFFSET_PLUS || CLAR_OFFSET_MINUS
  *
  * Returns:     RIG_OK if all called functions are successful,
- *              otherwise returns error from called functiion
+ *              otherwise returns error from called function
  *
  * Assumes:     rit doesn't exceed tuning limits of rig
  */
@@ -2134,7 +2131,7 @@ static int ft900_send_rit_freq(RIG *rig, unsigned char ci, shortfreq_t rit)
     rig_debug(RIG_DEBUG_TRACE, "%s: passed ci = %i\n", __func__, ci);
     rig_debug(RIG_DEBUG_TRACE, "%s: passed rit = %li Hz\n", __func__, rit);
 
-    priv = (struct ft900_priv_data *)rig->state.priv;
+    priv = (struct ft900_priv_data *)STATE(rig)->priv;
 
     if (ncmd[ci].ncomp)
     {
@@ -2168,7 +2165,7 @@ static int ft900_send_rit_freq(RIG *rig, unsigned char ci, shortfreq_t rit)
     priv->p_cmd[P1] = p1;         /* ick */
     priv->p_cmd[P2] = p2;
 
-    err = write_block(&rig->state.rigport, (unsigned char *) &priv->p_cmd,
+    err = write_block(RIGPORT(rig), (unsigned char *) &priv->p_cmd,
                       YAESU_CMD_LENGTH);
 
     if (err != RIG_OK)
