@@ -1,2 +1,2 @@
 /* This date time is from the last non-merge commit to Hamlib. */
-#define HAMLIBDATETIME "2025-06-10T00:52:44Z SHA=371db9"
+#define HAMLIBDATETIME "2025-07-18T18:23:23Z SHA=59e3d1"
