@@ -1781,7 +1781,7 @@ void usage()
         "  -S, --serial-speed2=BAUD      set serial speed of the virtual com port [default=115200]\n"
         "  -c, --civaddr=ID              set CI-V address, decimal (for Icom rigs only)\n"
         "  -C, --set-conf=PARM=VAL       set config parameters\n"
-        "  -B, --mapa2b                  maps set_freq on VFOA to VFOB -- useful for CW Skimmer\n"
+        "  -B, --mapa2b                  map set_freq on VFOA to VFOB -- useful for CW Skimmer\n"
         "  -L, --show-conf               list all config parameters\n"
         "  -l, --list                    list all model numbers and exit\n"
         "  -u, --dump-caps               dump capabilities and exit\n"
